# update_rpm
Script to download and install RPM files from the internet. 
Will skip downloading if the newest version of the package is already installed, and update otherwise.

## Install
`pip install update-rpm`

## Usage
See `update_rpm --help` for full overview.
See `update_rpm preset --help` for presets to choose from and usage examples.
